use std::path::Path;
use axum_client_ip::SecureClientIpSource;
use std::net::SocketAddr;

#[derive(serde::Deserialize)]
pub struct EchoIpServiceConfig {
	server: ServerConfig,
	dns: DnsConfig,
	geoip: GeoIpConfig,
	template: TemplateConfig,
}

#[derive(serde::Deserialize)]
pub struct ServerConfig {
	listen_on: SocketAddr,
	ip_header: SecureClientIpSource,
}

#[derive(serde::Deserialize)]
pub struct DnsConfig {
	allow_forward_lookup: bool,
	allow_reverse_lookup: bool,
	hide_private_range_ips: bool,
	hidden_suffixes: Vec<String>,
	//Future Idea: allow custom resolver
}

#[derive(serde::Deserialize)]
pub struct GeoIpConfig {
	asn_database: Option<String>,
	location_database: Option<String>,
}

#[derive(serde::Deserialize)]
pub struct TemplateConfig {
	template_location: String,
}

impl Default for ServerConfig {
	fn default() -> Self {
		ServerConfig {
			listen_on: "127.0.0.1:3000",
			ip_header: SecureClientIpSource::RightmostXForwardedFor,
		}
	}
}

impl Default for DnsConfig {
	fn default() -> Self {
		DnsConfig {
			allow_forward_lookup: true;
			allow_reverse_lookup: false;
			hide_private_range_ips: true;
			hidden_suffixes: Vec::new();
		}
	}
}
